# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class ApplicationResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uri': 'str',
        'date_created': 'str',
        'date_updated': 'str',
        'revision': 'int',
        'account_id': 'str',
        'application_id': 'str',
        'alias': 'str',
        'voice_url': 'str',
        'voice_fallback_url': 'str',
        'call_connect_url': 'str',
        'status_callback_url': 'str',
        'sms_url': 'str',
        'sms_fallback_url': 'str'
    }

    attribute_map = {
        'uri': 'uri',
        'date_created': 'dateCreated',
        'date_updated': 'dateUpdated',
        'revision': 'revision',
        'account_id': 'accountId',
        'application_id': 'applicationId',
        'alias': 'alias',
        'voice_url': 'voiceUrl',
        'voice_fallback_url': 'voiceFallbackUrl',
        'call_connect_url': 'callConnectUrl',
        'status_callback_url': 'statusCallbackUrl',
        'sms_url': 'smsUrl',
        'sms_fallback_url': 'smsFallbackUrl'
    }

    def __init__(self, uri=None, date_created=None, date_updated=None, revision=None, account_id=None, application_id=None, alias=None, voice_url=None, voice_fallback_url=None, call_connect_url=None, status_callback_url=None, sms_url=None, sms_fallback_url=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uri = None
        self._date_created = None
        self._date_updated = None
        self._revision = None
        self._account_id = None
        self._application_id = None
        self._alias = None
        self._voice_url = None
        self._voice_fallback_url = None
        self._call_connect_url = None
        self._status_callback_url = None
        self._sms_url = None
        self._sms_fallback_url = None
        self.discriminator = None

        if uri is not None:
            self.uri = uri
        if date_created is not None:
            self.date_created = date_created
        if date_updated is not None:
            self.date_updated = date_updated
        if revision is not None:
            self.revision = revision
        if account_id is not None:
            self.account_id = account_id
        if application_id is not None:
            self.application_id = application_id
        if alias is not None:
            self.alias = alias
        if voice_url is not None:
            self.voice_url = voice_url
        if voice_fallback_url is not None:
            self.voice_fallback_url = voice_fallback_url
        if call_connect_url is not None:
            self.call_connect_url = call_connect_url
        if status_callback_url is not None:
            self.status_callback_url = status_callback_url
        if sms_url is not None:
            self.sms_url = sms_url
        if sms_fallback_url is not None:
            self.sms_fallback_url = sms_fallback_url

    @property
    def uri(self):
        """Gets the uri of this ApplicationResult.  # noqa: E501

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :return: The uri of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this ApplicationResult.

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :param uri: The uri of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def date_created(self):
        """Gets the date_created of this ApplicationResult.  # noqa: E501

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_created of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ApplicationResult.

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_created: The date_created of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._date_created = date_created

    @property
    def date_updated(self):
        """Gets the date_updated of this ApplicationResult.  # noqa: E501

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_updated of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._date_updated

    @date_updated.setter
    def date_updated(self, date_updated):
        """Sets the date_updated of this ApplicationResult.

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_updated: The date_updated of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._date_updated = date_updated

    @property
    def revision(self):
        """Gets the revision of this ApplicationResult.  # noqa: E501

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :return: The revision of this ApplicationResult.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this ApplicationResult.

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :param revision: The revision of this ApplicationResult.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def account_id(self):
        """Gets the account_id of this ApplicationResult.  # noqa: E501

        ID of the account that owns this phone number.  # noqa: E501

        :return: The account_id of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ApplicationResult.

        ID of the account that owns this phone number.  # noqa: E501

        :param account_id: The account_id of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def application_id(self):
        """Gets the application_id of this ApplicationResult.  # noqa: E501

        ID of the Application that FreeClimb should contact if a Call or SMS arrives for this phone number or a Call from this number is placed. An incoming phone number is not useful until associated with an applicationId.  # noqa: E501

        :return: The application_id of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this ApplicationResult.

        ID of the Application that FreeClimb should contact if a Call or SMS arrives for this phone number or a Call from this number is placed. An incoming phone number is not useful until associated with an applicationId.  # noqa: E501

        :param application_id: The application_id of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def alias(self):
        """Gets the alias of this ApplicationResult.  # noqa: E501

        Description for this phone number. Typically the conventionally-formatted version of the phone number.  # noqa: E501

        :return: The alias of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this ApplicationResult.

        Description for this phone number. Typically the conventionally-formatted version of the phone number.  # noqa: E501

        :param alias: The alias of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def voice_url(self):
        """Gets the voice_url of this ApplicationResult.  # noqa: E501

        The URL FreeClimb will request when a phone number assigned to this Application receives a Call. Used for inbound calls only.  # noqa: E501

        :return: The voice_url of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._voice_url

    @voice_url.setter
    def voice_url(self, voice_url):
        """Sets the voice_url of this ApplicationResult.

        The URL FreeClimb will request when a phone number assigned to this Application receives a Call. Used for inbound calls only.  # noqa: E501

        :param voice_url: The voice_url of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._voice_url = voice_url

    @property
    def voice_fallback_url(self):
        """Gets the voice_fallback_url of this ApplicationResult.  # noqa: E501

        The URL that FreeClimb will request if it times out waiting for a response from the voiceUrl. Used for inbound calls only.  # noqa: E501

        :return: The voice_fallback_url of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._voice_fallback_url

    @voice_fallback_url.setter
    def voice_fallback_url(self, voice_fallback_url):
        """Sets the voice_fallback_url of this ApplicationResult.

        The URL that FreeClimb will request if it times out waiting for a response from the voiceUrl. Used for inbound calls only.  # noqa: E501

        :param voice_fallback_url: The voice_fallback_url of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._voice_fallback_url = voice_fallback_url

    @property
    def call_connect_url(self):
        """Gets the call_connect_url of this ApplicationResult.  # noqa: E501

        The URL to which FreeClimb will make a POST request informing the result of the outbound Call request. The status property of the request message specifies if the Call was connected or not.  # noqa: E501

        :return: The call_connect_url of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._call_connect_url

    @call_connect_url.setter
    def call_connect_url(self, call_connect_url):
        """Sets the call_connect_url of this ApplicationResult.

        The URL to which FreeClimb will make a POST request informing the result of the outbound Call request. The status property of the request message specifies if the Call was connected or not.  # noqa: E501

        :param call_connect_url: The call_connect_url of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._call_connect_url = call_connect_url

    @property
    def status_callback_url(self):
        """Gets the status_callback_url of this ApplicationResult.  # noqa: E501

        A URL to which FreeClimb will make a POST request when the Call ends to notify this app.  # noqa: E501

        :return: The status_callback_url of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._status_callback_url

    @status_callback_url.setter
    def status_callback_url(self, status_callback_url):
        """Sets the status_callback_url of this ApplicationResult.

        A URL to which FreeClimb will make a POST request when the Call ends to notify this app.  # noqa: E501

        :param status_callback_url: The status_callback_url of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._status_callback_url = status_callback_url

    @property
    def sms_url(self):
        """Gets the sms_url of this ApplicationResult.  # noqa: E501

        The URL FreeClimb will request when a phone number assigned to this Application receives an incoming SMS message. Used for inbound SMS only.  # noqa: E501

        :return: The sms_url of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._sms_url

    @sms_url.setter
    def sms_url(self, sms_url):
        """Sets the sms_url of this ApplicationResult.

        The URL FreeClimb will request when a phone number assigned to this Application receives an incoming SMS message. Used for inbound SMS only.  # noqa: E501

        :param sms_url: The sms_url of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._sms_url = sms_url

    @property
    def sms_fallback_url(self):
        """Gets the sms_fallback_url of this ApplicationResult.  # noqa: E501

        The URL that FreeClimb will request if it times out waiting for a response from the smsUrl. Used for inbound SMS only.  # noqa: E501

        :return: The sms_fallback_url of this ApplicationResult.  # noqa: E501
        :rtype: str
        """
        return self._sms_fallback_url

    @sms_fallback_url.setter
    def sms_fallback_url(self, sms_fallback_url):
        """Sets the sms_fallback_url of this ApplicationResult.

        The URL that FreeClimb will request if it times out waiting for a response from the smsUrl. Used for inbound SMS only.  # noqa: E501

        :param sms_fallback_url: The sms_fallback_url of this ApplicationResult.  # noqa: E501
        :type: str
        """

        self._sms_fallback_url = sms_fallback_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationResult):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class ConferenceList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total': 'int',
        'start': 'int',
        'end': 'int',
        'page': 'int',
        'num_pages': 'int',
        'page_size': 'int',
        'next_page_uri': 'str',
        'conferences': 'list[ConferenceResult]'
    }

    attribute_map = {
        'total': 'total',
        'start': 'start',
        'end': 'end',
        'page': 'page',
        'num_pages': 'numPages',
        'page_size': 'pageSize',
        'next_page_uri': 'nextPageUri',
        'conferences': 'conferences'
    }

    def __init__(self, total=None, start=None, end=None, page=None, num_pages=None, page_size=None, next_page_uri=None, conferences=None, local_vars_configuration=None):  # noqa: E501
        """ConferenceList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total = None
        self._start = None
        self._end = None
        self._page = None
        self._num_pages = None
        self._page_size = None
        self._next_page_uri = None
        self._conferences = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if start is not None:
            self.start = start
        if end is not None:
            self.end = end
        if page is not None:
            self.page = page
        if num_pages is not None:
            self.num_pages = num_pages
        if page_size is not None:
            self.page_size = page_size
        if next_page_uri is not None:
            self.next_page_uri = next_page_uri
        if conferences is not None:
            self.conferences = conferences

    @property
    def total(self):
        """Gets the total of this ConferenceList.  # noqa: E501

        Total amount of requested resource.  # noqa: E501

        :return: The total of this ConferenceList.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ConferenceList.

        Total amount of requested resource.  # noqa: E501

        :param total: The total of this ConferenceList.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def start(self):
        """Gets the start of this ConferenceList.  # noqa: E501

        Resource index at start of current page  # noqa: E501

        :return: The start of this ConferenceList.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this ConferenceList.

        Resource index at start of current page  # noqa: E501

        :param start: The start of this ConferenceList.  # noqa: E501
        :type: int
        """

        self._start = start

    @property
    def end(self):
        """Gets the end of this ConferenceList.  # noqa: E501

        Resource index at end of current page  # noqa: E501

        :return: The end of this ConferenceList.  # noqa: E501
        :rtype: int
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this ConferenceList.

        Resource index at end of current page  # noqa: E501

        :param end: The end of this ConferenceList.  # noqa: E501
        :type: int
        """

        self._end = end

    @property
    def page(self):
        """Gets the page of this ConferenceList.  # noqa: E501

        Current page  # noqa: E501

        :return: The page of this ConferenceList.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this ConferenceList.

        Current page  # noqa: E501

        :param page: The page of this ConferenceList.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def num_pages(self):
        """Gets the num_pages of this ConferenceList.  # noqa: E501

        Total number of pages  # noqa: E501

        :return: The num_pages of this ConferenceList.  # noqa: E501
        :rtype: int
        """
        return self._num_pages

    @num_pages.setter
    def num_pages(self, num_pages):
        """Sets the num_pages of this ConferenceList.

        Total number of pages  # noqa: E501

        :param num_pages: The num_pages of this ConferenceList.  # noqa: E501
        :type: int
        """

        self._num_pages = num_pages

    @property
    def page_size(self):
        """Gets the page_size of this ConferenceList.  # noqa: E501

        Number of items per page  # noqa: E501

        :return: The page_size of this ConferenceList.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this ConferenceList.

        Number of items per page  # noqa: E501

        :param page_size: The page_size of this ConferenceList.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def next_page_uri(self):
        """Gets the next_page_uri of this ConferenceList.  # noqa: E501

        Uri to retrieve the next page of items  # noqa: E501

        :return: The next_page_uri of this ConferenceList.  # noqa: E501
        :rtype: str
        """
        return self._next_page_uri

    @next_page_uri.setter
    def next_page_uri(self, next_page_uri):
        """Sets the next_page_uri of this ConferenceList.

        Uri to retrieve the next page of items  # noqa: E501

        :param next_page_uri: The next_page_uri of this ConferenceList.  # noqa: E501
        :type: str
        """

        self._next_page_uri = next_page_uri

    @property
    def conferences(self):
        """Gets the conferences of this ConferenceList.  # noqa: E501


        :return: The conferences of this ConferenceList.  # noqa: E501
        :rtype: list[ConferenceResult]
        """
        return self._conferences

    @conferences.setter
    def conferences(self, conferences):
        """Sets the conferences of this ConferenceList.


        :param conferences: The conferences of this ConferenceList.  # noqa: E501
        :type: list[ConferenceResult]
        """

        self._conferences = conferences

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConferenceList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConferenceList):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class MakeCallRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_from': 'str',
        'to': 'str',
        'application_id': 'str',
        'send_digits': 'str',
        'if_machine': 'str',
        'if_machine_url': 'str',
        'timeout': 'int',
        'parent_call_id': 'str'
    }

    attribute_map = {
        '_from': 'from',
        'to': 'to',
        'application_id': 'applicationId',
        'send_digits': 'sendDigits',
        'if_machine': 'ifMachine',
        'if_machine_url': 'ifMachineUrl',
        'timeout': 'timeout',
        'parent_call_id': 'parentCallId'
    }

    def __init__(self, _from=None, to=None, application_id=None, send_digits=None, if_machine=None, if_machine_url=None, timeout=None, parent_call_id=None, local_vars_configuration=None):  # noqa: E501
        """MakeCallRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.__from = None
        self._to = None
        self._application_id = None
        self._send_digits = None
        self._if_machine = None
        self._if_machine_url = None
        self._timeout = None
        self._parent_call_id = None
        self.discriminator = None

        self._from = _from
        self.to = to
        self.application_id = application_id
        if send_digits is not None:
            self.send_digits = send_digits
        if if_machine is not None:
            self.if_machine = if_machine
        if if_machine_url is not None:
            self.if_machine_url = if_machine_url
        if timeout is not None:
            self.timeout = timeout
        if parent_call_id is not None:
            self.parent_call_id = parent_call_id

    @property
    def _from(self):
        """Gets the _from of this MakeCallRequest.  # noqa: E501

        Phone number to use as the caller ID. This can be: (a) The To or From number provided in FreeClimb's initial request to your app or (b) Any incoming phone number you have purchased from FreeClimb.  # noqa: E501

        :return: The _from of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this MakeCallRequest.

        Phone number to use as the caller ID. This can be: (a) The To or From number provided in FreeClimb's initial request to your app or (b) Any incoming phone number you have purchased from FreeClimb.  # noqa: E501

        :param _from: The _from of this MakeCallRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and _from is None:  # noqa: E501
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this MakeCallRequest.  # noqa: E501

        Phone number to place the Call to.  # noqa: E501

        :return: The to of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this MakeCallRequest.

        Phone number to place the Call to.  # noqa: E501

        :param to: The to of this MakeCallRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def application_id(self):
        """Gets the application_id of this MakeCallRequest.  # noqa: E501

        ID of the application FreeClimb should use to handle this phone call. FreeClimb will use the `callConnectUrl` and `statusCallbackUrl` set on the application. The application must have a `callConnectUrl` associated with it or an error will be returned. The application’s `voiceUrl` parameter is not used for outbound calls.  # noqa: E501

        :return: The application_id of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this MakeCallRequest.

        ID of the application FreeClimb should use to handle this phone call. FreeClimb will use the `callConnectUrl` and `statusCallbackUrl` set on the application. The application must have a `callConnectUrl` associated with it or an error will be returned. The application’s `voiceUrl` parameter is not used for outbound calls.  # noqa: E501

        :param application_id: The application_id of this MakeCallRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and application_id is None:  # noqa: E501
            raise ValueError("Invalid value for `application_id`, must not be `None`")  # noqa: E501

        self._application_id = application_id

    @property
    def send_digits(self):
        """Gets the send_digits of this MakeCallRequest.  # noqa: E501

        String of digits to dial after connecting to the number. It can include digits `0-9`, `*`, and `#`, and allows embedding a pause between the output of individual digits. The default pause is 500 milliseconds. So, a string such as *1234#* will be played in 2 seconds because of the 4 standard pauses implied within the string. A custom pause is specified by including a positive integer wrapped in curly braces: {n}. For more information, see **sendDigits examples** below.  # noqa: E501

        :return: The send_digits of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self._send_digits

    @send_digits.setter
    def send_digits(self, send_digits):
        """Sets the send_digits of this MakeCallRequest.

        String of digits to dial after connecting to the number. It can include digits `0-9`, `*`, and `#`, and allows embedding a pause between the output of individual digits. The default pause is 500 milliseconds. So, a string such as *1234#* will be played in 2 seconds because of the 4 standard pauses implied within the string. A custom pause is specified by including a positive integer wrapped in curly braces: {n}. For more information, see **sendDigits examples** below.  # noqa: E501

        :param send_digits: The send_digits of this MakeCallRequest.  # noqa: E501
        :type: str
        """

        self._send_digits = send_digits

    @property
    def if_machine(self):
        """Gets the if_machine of this MakeCallRequest.  # noqa: E501

        Specifies how FreeClimb should handle this Call if an answering machine answers it.  # noqa: E501

        :return: The if_machine of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self._if_machine

    @if_machine.setter
    def if_machine(self, if_machine):
        """Sets the if_machine of this MakeCallRequest.

        Specifies how FreeClimb should handle this Call if an answering machine answers it.  # noqa: E501

        :param if_machine: The if_machine of this MakeCallRequest.  # noqa: E501
        :type: str
        """

        self._if_machine = if_machine

    @property
    def if_machine_url(self):
        """Gets the if_machine_url of this MakeCallRequest.  # noqa: E501

        This attribute specifies a URL to which FreeClimb will make a POST request when an answering machine or a fax machine is detected. This URL is required if the ifMachine flag is set to redirect. When ifMachine is set to hangup, ifMachineUrl must not be included in the request. For more information, see **ifMachineUrl example** below.  # noqa: E501

        :return: The if_machine_url of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self._if_machine_url

    @if_machine_url.setter
    def if_machine_url(self, if_machine_url):
        """Sets the if_machine_url of this MakeCallRequest.

        This attribute specifies a URL to which FreeClimb will make a POST request when an answering machine or a fax machine is detected. This URL is required if the ifMachine flag is set to redirect. When ifMachine is set to hangup, ifMachineUrl must not be included in the request. For more information, see **ifMachineUrl example** below.  # noqa: E501

        :param if_machine_url: The if_machine_url of this MakeCallRequest.  # noqa: E501
        :type: str
        """

        self._if_machine_url = if_machine_url

    @property
    def timeout(self):
        """Gets the timeout of this MakeCallRequest.  # noqa: E501

        Number of seconds that FreeClimb should allow the phone to ring before assuming there is no answer. Default is 30 seconds. Maximum allowed ring-time is determined by the target phone's provider. Note that most providers limit ring-time to 120 seconds.  # noqa: E501

        :return: The timeout of this MakeCallRequest.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this MakeCallRequest.

        Number of seconds that FreeClimb should allow the phone to ring before assuming there is no answer. Default is 30 seconds. Maximum allowed ring-time is determined by the target phone's provider. Note that most providers limit ring-time to 120 seconds.  # noqa: E501

        :param timeout: The timeout of this MakeCallRequest.  # noqa: E501
        :type: int
        """

        self._timeout = timeout

    @property
    def parent_call_id(self):
        """Gets the parent_call_id of this MakeCallRequest.  # noqa: E501

        The ID of the parent Call in the case that this new Call is meant to be treated as a child of an existing Call. This attribute should be included when possible to reduce latency when adding child calls to Conferences containing the parent Call. A call can only be used as a parent once the call is in progress or as an inbound call that is still ringing.  An outbound call is considered to be in progress once the outdialConnect or outdialApiConnect webhook is invoked.  An inbound call is ringing when the inbound webhook is invoked.  # noqa: E501

        :return: The parent_call_id of this MakeCallRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_call_id

    @parent_call_id.setter
    def parent_call_id(self, parent_call_id):
        """Sets the parent_call_id of this MakeCallRequest.

        The ID of the parent Call in the case that this new Call is meant to be treated as a child of an existing Call. This attribute should be included when possible to reduce latency when adding child calls to Conferences containing the parent Call. A call can only be used as a parent once the call is in progress or as an inbound call that is still ringing.  An outbound call is considered to be in progress once the outdialConnect or outdialApiConnect webhook is invoked.  An inbound call is ringing when the inbound webhook is invoked.  # noqa: E501

        :param parent_call_id: The parent_call_id of this MakeCallRequest.  # noqa: E501
        :type: str
        """

        self._parent_call_id = parent_call_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MakeCallRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MakeCallRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class ApplicationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alias': 'str',
        'voice_url': 'str',
        'voice_fallback_url': 'str',
        'call_connect_url': 'str',
        'status_callback_url': 'str',
        'sms_url': 'str',
        'sms_fallback_url': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'voice_url': 'voiceUrl',
        'voice_fallback_url': 'voiceFallbackUrl',
        'call_connect_url': 'callConnectUrl',
        'status_callback_url': 'statusCallbackUrl',
        'sms_url': 'smsUrl',
        'sms_fallback_url': 'smsFallbackUrl'
    }

    def __init__(self, alias=None, voice_url=None, voice_fallback_url=None, call_connect_url=None, status_callback_url=None, sms_url=None, sms_fallback_url=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alias = None
        self._voice_url = None
        self._voice_fallback_url = None
        self._call_connect_url = None
        self._status_callback_url = None
        self._sms_url = None
        self._sms_fallback_url = None
        self.discriminator = None

        if alias is not None:
            self.alias = alias
        if voice_url is not None:
            self.voice_url = voice_url
        if voice_fallback_url is not None:
            self.voice_fallback_url = voice_fallback_url
        if call_connect_url is not None:
            self.call_connect_url = call_connect_url
        if status_callback_url is not None:
            self.status_callback_url = status_callback_url
        if sms_url is not None:
            self.sms_url = sms_url
        if sms_fallback_url is not None:
            self.sms_fallback_url = sms_fallback_url

    @property
    def alias(self):
        """Gets the alias of this ApplicationRequest.  # noqa: E501

        A human readable description of the application, with maximum length 64 characters.  # noqa: E501

        :return: The alias of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this ApplicationRequest.

        A human readable description of the application, with maximum length 64 characters.  # noqa: E501

        :param alias: The alias of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def voice_url(self):
        """Gets the voice_url of this ApplicationRequest.  # noqa: E501

        The URL that FreeClimb will request when an inbound call arrives on a phone number assigned to this application. Used only for inbound calls.  # noqa: E501

        :return: The voice_url of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._voice_url

    @voice_url.setter
    def voice_url(self, voice_url):
        """Sets the voice_url of this ApplicationRequest.

        The URL that FreeClimb will request when an inbound call arrives on a phone number assigned to this application. Used only for inbound calls.  # noqa: E501

        :param voice_url: The voice_url of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._voice_url = voice_url

    @property
    def voice_fallback_url(self):
        """Gets the voice_fallback_url of this ApplicationRequest.  # noqa: E501

        The URL that FreeClimb will request if it times out waiting for a response from the voiceUrl. Used for inbound calls only. Note: A PerCL response is expected to control the inbound call.  # noqa: E501

        :return: The voice_fallback_url of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._voice_fallback_url

    @voice_fallback_url.setter
    def voice_fallback_url(self, voice_fallback_url):
        """Sets the voice_fallback_url of this ApplicationRequest.

        The URL that FreeClimb will request if it times out waiting for a response from the voiceUrl. Used for inbound calls only. Note: A PerCL response is expected to control the inbound call.  # noqa: E501

        :param voice_fallback_url: The voice_fallback_url of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._voice_fallback_url = voice_fallback_url

    @property
    def call_connect_url(self):
        """Gets the call_connect_url of this ApplicationRequest.  # noqa: E501

        The URL that FreeClimb will request when an outbound call request is complete. Used for outbound calls only.  Note: A PerCL response is expected if the outbound call is connected (status=InProgress) to control the call.  # noqa: E501

        :return: The call_connect_url of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._call_connect_url

    @call_connect_url.setter
    def call_connect_url(self, call_connect_url):
        """Sets the call_connect_url of this ApplicationRequest.

        The URL that FreeClimb will request when an outbound call request is complete. Used for outbound calls only.  Note: A PerCL response is expected if the outbound call is connected (status=InProgress) to control the call.  # noqa: E501

        :param call_connect_url: The call_connect_url of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._call_connect_url = call_connect_url

    @property
    def status_callback_url(self):
        """Gets the status_callback_url of this ApplicationRequest.  # noqa: E501

        The URL that FreeClimb will request to pass call status (such as call ended) to the application.  Note: This is a notification only; any PerCL returned will be ignored.  # noqa: E501

        :return: The status_callback_url of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._status_callback_url

    @status_callback_url.setter
    def status_callback_url(self, status_callback_url):
        """Sets the status_callback_url of this ApplicationRequest.

        The URL that FreeClimb will request to pass call status (such as call ended) to the application.  Note: This is a notification only; any PerCL returned will be ignored.  # noqa: E501

        :param status_callback_url: The status_callback_url of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._status_callback_url = status_callback_url

    @property
    def sms_url(self):
        """Gets the sms_url of this ApplicationRequest.  # noqa: E501

        The URL that FreeClimb will request when a phone number assigned to this application receives an incoming SMS message. Used for inbound SMS only.  Note: Any PerCL returned will be ignored.  # noqa: E501

        :return: The sms_url of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._sms_url

    @sms_url.setter
    def sms_url(self, sms_url):
        """Sets the sms_url of this ApplicationRequest.

        The URL that FreeClimb will request when a phone number assigned to this application receives an incoming SMS message. Used for inbound SMS only.  Note: Any PerCL returned will be ignored.  # noqa: E501

        :param sms_url: The sms_url of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._sms_url = sms_url

    @property
    def sms_fallback_url(self):
        """Gets the sms_fallback_url of this ApplicationRequest.  # noqa: E501

        The URL that FreeClimb will request if it times out waiting for a response from the smsUrl. Used for inbound SMS only.  Note: Any PerCL returned will be ignored.  # noqa: E501

        :return: The sms_fallback_url of this ApplicationRequest.  # noqa: E501
        :rtype: str
        """
        return self._sms_fallback_url

    @sms_fallback_url.setter
    def sms_fallback_url(self, sms_fallback_url):
        """Sets the sms_fallback_url of this ApplicationRequest.

        The URL that FreeClimb will request if it times out waiting for a response from the smsUrl. Used for inbound SMS only.  Note: Any PerCL returned will be ignored.  # noqa: E501

        :param sms_fallback_url: The sms_fallback_url of this ApplicationRequest.  # noqa: E501
        :type: str
        """

        self._sms_fallback_url = sms_fallback_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class Say(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'text': 'str',
        'language': 'str',
        'loop': 'int',
        'conference_id': 'str',
        'enforce_pci': 'bool'
    }

    attribute_map = {
        'text': 'text',
        'language': 'language',
        'loop': 'loop',
        'conference_id': 'conferenceId',
        'enforce_pci': 'enforcePCI'
    }

    def __init__(self, text=None, language=None, loop=None, conference_id=None, enforce_pci=None, local_vars_configuration=None):  # noqa: E501
        """Say - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._text = None
        self._language = None
        self._loop = None
        self._conference_id = None
        self._enforce_pci = None
        self.discriminator = None

        self.text = text
        if language is not None:
            self.language = language
        if loop is not None:
            self.loop = loop
        if conference_id is not None:
            self.conference_id = conference_id
        if enforce_pci is not None:
            self.enforce_pci = enforce_pci

    @property
    def text(self):
        """Gets the text of this Say.  # noqa: E501

        The message to be played to the caller using TTS. The size of the string is limited to 4 KB (or 4,096 bytes). An empty string will cause the command to be skipped.  # noqa: E501

        :return: The text of this Say.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Say.

        The message to be played to the caller using TTS. The size of the string is limited to 4 KB (or 4,096 bytes). An empty string will cause the command to be skipped.  # noqa: E501

        :param text: The text of this Say.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def language(self):
        """Gets the language of this Say.  # noqa: E501

        Language and (by implication) the locale to use. This implies the accent and pronunciations to be usde for the TTS. The complete list of valid values for the language attribute is shown below.  # noqa: E501

        :return: The language of this Say.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Say.

        Language and (by implication) the locale to use. This implies the accent and pronunciations to be usde for the TTS. The complete list of valid values for the language attribute is shown below.  # noqa: E501

        :param language: The language of this Say.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def loop(self):
        """Gets the loop of this Say.  # noqa: E501

        Number of times the text is said. Specifying '0' causes the `Say` action to loop until the Call is hung up.  # noqa: E501

        :return: The loop of this Say.  # noqa: E501
        :rtype: int
        """
        return self._loop

    @loop.setter
    def loop(self, loop):
        """Sets the loop of this Say.

        Number of times the text is said. Specifying '0' causes the `Say` action to loop until the Call is hung up.  # noqa: E501

        :param loop: The loop of this Say.  # noqa: E501
        :type: int
        """

        self._loop = loop

    @property
    def conference_id(self):
        """Gets the conference_id of this Say.  # noqa: E501

        D of the Conference the speech should be rendered to. If this is not specified, the speech is by default rendered to the Caller associated with the call leg that corresponds to the current PerCL execution context. The call leg associated with this command must be in the specified Conference or the command will return an error.  # noqa: E501

        :return: The conference_id of this Say.  # noqa: E501
        :rtype: str
        """
        return self._conference_id

    @conference_id.setter
    def conference_id(self, conference_id):
        """Sets the conference_id of this Say.

        D of the Conference the speech should be rendered to. If this is not specified, the speech is by default rendered to the Caller associated with the call leg that corresponds to the current PerCL execution context. The call leg associated with this command must be in the specified Conference or the command will return an error.  # noqa: E501

        :param conference_id: The conference_id of this Say.  # noqa: E501
        :type: str
        """

        self._conference_id = conference_id

    @property
    def enforce_pci(self):
        """Gets the enforce_pci of this Say.  # noqa: E501

        Parameter `enforcePCI` will not log the `text` as required by PCI compliance.  # noqa: E501

        :return: The enforce_pci of this Say.  # noqa: E501
        :rtype: bool
        """
        return self._enforce_pci

    @enforce_pci.setter
    def enforce_pci(self, enforce_pci):
        """Sets the enforce_pci of this Say.

        Parameter `enforcePCI` will not log the `text` as required by PCI compliance.  # noqa: E501

        :param enforce_pci: The enforce_pci of this Say.  # noqa: E501
        :type: bool
        """

        self._enforce_pci = enforce_pci

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Say):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Say):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class CreateConference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'alias': 'bool',
        'play_beep': 'str',
        'record': 'bool',
        'status_callback_url': 'bool',
        'wait_url': 'str'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'alias': 'alias',
        'play_beep': 'playBeep',
        'record': 'record',
        'status_callback_url': 'statusCallbackUrl',
        'wait_url': 'waitUrl'
    }

    def __init__(self, action_url=None, alias=None, play_beep=None, record=None, status_callback_url=None, wait_url=None, local_vars_configuration=None):  # noqa: E501
        """CreateConference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_url = None
        self._alias = None
        self._play_beep = None
        self._record = None
        self._status_callback_url = None
        self._wait_url = None
        self.discriminator = None

        self.action_url = action_url
        if alias is not None:
            self.alias = alias
        if play_beep is not None:
            self.play_beep = play_beep
        if record is not None:
            self.record = record
        if status_callback_url is not None:
            self.status_callback_url = status_callback_url
        if wait_url is not None:
            self.wait_url = wait_url

    @property
    def action_url(self):
        """Gets the action_url of this CreateConference.  # noqa: E501

         This URL is invoked once the Conference is successfully created. Actions on the Conference, such as adding Participants, can be performed via the PerCL script returned in the response.   # noqa: E501

        :return: The action_url of this CreateConference.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this CreateConference.

         This URL is invoked once the Conference is successfully created. Actions on the Conference, such as adding Participants, can be performed via the PerCL script returned in the response.   # noqa: E501

        :param action_url: The action_url of this CreateConference.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def alias(self):
        """Gets the alias of this CreateConference.  # noqa: E501

        Descriptive name for the Conference.   # noqa: E501

        :return: The alias of this CreateConference.  # noqa: E501
        :rtype: bool
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this CreateConference.

        Descriptive name for the Conference.   # noqa: E501

        :param alias: The alias of this CreateConference.  # noqa: E501
        :type: bool
        """

        self._alias = alias

    @property
    def play_beep(self):
        """Gets the play_beep of this CreateConference.  # noqa: E501

        Indicates whether to play a beep when a Participant enters or leaves the Conference. either `always`, `never`, `entryOnly`, or `exitOnly`. Leaving this unset will make conference default to `always`   # noqa: E501

        :return: The play_beep of this CreateConference.  # noqa: E501
        :rtype: str
        """
        return self._play_beep

    @play_beep.setter
    def play_beep(self, play_beep):
        """Sets the play_beep of this CreateConference.

        Indicates whether to play a beep when a Participant enters or leaves the Conference. either `always`, `never`, `entryOnly`, or `exitOnly`. Leaving this unset will make conference default to `always`   # noqa: E501

        :param play_beep: The play_beep of this CreateConference.  # noqa: E501
        :type: str
        """

        self._play_beep = play_beep

    @property
    def record(self):
        """Gets the record of this CreateConference.  # noqa: E501

        When set to `true`, the entire Conference is recorded. The `statusCallbackUrl` of the Conference will receive a `conferenceRecordingEnded` Webhook when the Conference transitions from the `inProgress` to empty state.  # noqa: E501

        :return: The record of this CreateConference.  # noqa: E501
        :rtype: bool
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this CreateConference.

        When set to `true`, the entire Conference is recorded. The `statusCallbackUrl` of the Conference will receive a `conferenceRecordingEnded` Webhook when the Conference transitions from the `inProgress` to empty state.  # noqa: E501

        :param record: The record of this CreateConference.  # noqa: E501
        :type: bool
        """

        self._record = record

    @property
    def status_callback_url(self):
        """Gets the status_callback_url of this CreateConference.  # noqa: E501

        This URL is invoked when the status of the Conference changes or when a recording of the Conference has become available.  # noqa: E501

        :return: The status_callback_url of this CreateConference.  # noqa: E501
        :rtype: bool
        """
        return self._status_callback_url

    @status_callback_url.setter
    def status_callback_url(self, status_callback_url):
        """Sets the status_callback_url of this CreateConference.

        This URL is invoked when the status of the Conference changes or when a recording of the Conference has become available.  # noqa: E501

        :param status_callback_url: The status_callback_url of this CreateConference.  # noqa: E501
        :type: bool
        """

        self._status_callback_url = status_callback_url

    @property
    def wait_url(self):
        """Gets the wait_url of this CreateConference.  # noqa: E501

        If specified, this URL provides the custom hold music for the Conference when it is in the populated state. This attribute is always fetched using HTTP GET and is fetched just once – when the Conference is created. The URL must be an audio file that is reachable and readable by FreeClimb.  # noqa: E501

        :return: The wait_url of this CreateConference.  # noqa: E501
        :rtype: str
        """
        return self._wait_url

    @wait_url.setter
    def wait_url(self, wait_url):
        """Sets the wait_url of this CreateConference.

        If specified, this URL provides the custom hold music for the Conference when it is in the populated state. This attribute is always fetched using HTTP GET and is fetched just once – when the Conference is created. The URL must be an audio file that is reachable and readable by FreeClimb.  # noqa: E501

        :param wait_url: The wait_url of this CreateConference.  # noqa: E501
        :type: str
        """

        self._wait_url = wait_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateConference):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class MessageRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uri': 'str',
        'date_created': 'str',
        'date_updated': 'str',
        'revision': 'int',
        '_from': 'str',
        'to': 'str',
        'text': 'str',
        'notification_url': 'str',
        'account_id': 'str'
    }

    attribute_map = {
        'uri': 'uri',
        'date_created': 'dateCreated',
        'date_updated': 'dateUpdated',
        'revision': 'revision',
        '_from': 'from',
        'to': 'to',
        'text': 'text',
        'notification_url': 'notificationUrl',
        'account_id': 'accountId'
    }

    def __init__(self, uri=None, date_created=None, date_updated=None, revision=None, _from=None, to=None, text=None, notification_url=None, account_id=None, local_vars_configuration=None):  # noqa: E501
        """MessageRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uri = None
        self._date_created = None
        self._date_updated = None
        self._revision = None
        self.__from = None
        self._to = None
        self._text = None
        self._notification_url = None
        self._account_id = None
        self.discriminator = None

        if uri is not None:
            self.uri = uri
        if date_created is not None:
            self.date_created = date_created
        if date_updated is not None:
            self.date_updated = date_updated
        if revision is not None:
            self.revision = revision
        self._from = _from
        self.to = to
        self.text = text
        if notification_url is not None:
            self.notification_url = notification_url
        if account_id is not None:
            self.account_id = account_id

    @property
    def uri(self):
        """Gets the uri of this MessageRequest.  # noqa: E501

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :return: The uri of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this MessageRequest.

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :param uri: The uri of this MessageRequest.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def date_created(self):
        """Gets the date_created of this MessageRequest.  # noqa: E501

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_created of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this MessageRequest.

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_created: The date_created of this MessageRequest.  # noqa: E501
        :type: str
        """

        self._date_created = date_created

    @property
    def date_updated(self):
        """Gets the date_updated of this MessageRequest.  # noqa: E501

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_updated of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._date_updated

    @date_updated.setter
    def date_updated(self, date_updated):
        """Sets the date_updated of this MessageRequest.

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_updated: The date_updated of this MessageRequest.  # noqa: E501
        :type: str
        """

        self._date_updated = date_updated

    @property
    def revision(self):
        """Gets the revision of this MessageRequest.  # noqa: E501

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :return: The revision of this MessageRequest.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this MessageRequest.

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :param revision: The revision of this MessageRequest.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def _from(self):
        """Gets the _from of this MessageRequest.  # noqa: E501

        Phone number to use as the sender. This must be an incoming phone number that you have purchased from FreeClimb.  # noqa: E501

        :return: The _from of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this MessageRequest.

        Phone number to use as the sender. This must be an incoming phone number that you have purchased from FreeClimb.  # noqa: E501

        :param _from: The _from of this MessageRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and _from is None:  # noqa: E501
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this MessageRequest.  # noqa: E501

        Phone number to receive the message. Must be within FreeClimb's service area.  # noqa: E501

        :return: The to of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this MessageRequest.

        Phone number to receive the message. Must be within FreeClimb's service area.  # noqa: E501

        :param to: The to of this MessageRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def text(self):
        """Gets the text of this MessageRequest.  # noqa: E501

        Text contained in the message (maximum 160 characters).   **Note:** For text, only ASCII characters are supported.  # noqa: E501

        :return: The text of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this MessageRequest.

        Text contained in the message (maximum 160 characters).   **Note:** For text, only ASCII characters are supported.  # noqa: E501

        :param text: The text of this MessageRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def notification_url(self):
        """Gets the notification_url of this MessageRequest.  # noqa: E501

        When the Message changes status, this URL is invoked using HTTP POST with the messageStatus parameters.  **Note:** This is a notification only; any PerCL returned is ignored.  # noqa: E501

        :return: The notification_url of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this MessageRequest.

        When the Message changes status, this URL is invoked using HTTP POST with the messageStatus parameters.  **Note:** This is a notification only; any PerCL returned is ignored.  # noqa: E501

        :param notification_url: The notification_url of this MessageRequest.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    @property
    def account_id(self):
        """Gets the account_id of this MessageRequest.  # noqa: E501

        String that uniquely identifies this account resource.  # noqa: E501

        :return: The account_id of this MessageRequest.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this MessageRequest.

        String that uniquely identifies this account resource.  # noqa: E501

        :param account_id: The account_id of this MessageRequest.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MessageRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import freeclimb
from freeclimb.models.say_all_of import SayAllOf  # noqa: E501
from freeclimb.rest import ApiException

class TestSayAllOf(unittest.TestCase):
    """SayAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SayAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = freeclimb.models.say_all_of.SayAllOf()  # noqa: E501
        if include_optional :
            return SayAllOf(
                text = '0', 
                language = '0', 
                loop = 56, 
                conference_id = '0', 
                enforce_pci = True
            )
        else :
            return SayAllOf(
                text = '0',
        )

    def testSayAllOf(self):
        """Test SayAllOf"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
